import { ElementRef, EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { Extension } from '@codemirror/state';
import { EditorView } from 'codemirror';
import * as i0 from "@angular/core";
export type Theme = 'light' | 'dark' | Extension;
export declare class CodeEditor implements OnChanges, OnInit, OnDestroy, ControlValueAccessor {
    private _elementRef;
    /**
     * The document or shadow root that the view lives in.
     *
     * https://codemirror.net/docs/ref/#view.EditorView.root
     */
    root?: Document | ShadowRoot;
    /** Editor's value. */
    get value(): string;
    set value(newValue: string);
    _value: string;
    /** Editor's theme. */
    theme: Theme;
    /** Editor's placecholder. */
    placeholder: string;
    /** Whether the editor is disabled.  */
    disabled: boolean;
    /** Whether the editor is readonly. */
    readonly: boolean;
    /** Whether focus on the editor when init. */
    autoFocus: boolean;
    /**
     * EditorState's [extensions](https://codemirror.net/docs/ref/#state.EditorStateConfig.extensions).
     * It includes the [basicSetup](https://codemirror.net/docs/ref/#codemirror.basicSetup) by default.
     */
    extensions: Extension[];
    /** Event emitted when the editor's value changes. */
    change: EventEmitter<string>;
    /** Event emitted when focus on the editor. */
    focus: EventEmitter<void>;
    /** Event emitted when the editor has lost focus. */
    blur: EventEmitter<void>;
    view?: EditorView | null;
    private _onChange;
    private _onTouched;
    constructor(_elementRef: ElementRef<Element>);
    /** Register a function to be called every time the view updates. */
    private _updateListener;
    /** Get the extensions of the editor. */
    getExtensions(): Extension[];
    /** Reconfigure the root extensions of the editor. */
    reconfigure(): void;
    /** Sets the editor's value. */
    setValue(value: string): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    writeValue(value: string): void;
    registerOnChange(fn: (value: string) => void): void;
    registerOnTouched(fn: () => void): void;
    setDisabledState(isDisabled: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CodeEditor, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CodeEditor, "code-editor", never, { "root": { "alias": "root"; "required": false; }; "value": { "alias": "value"; "required": false; }; "theme": { "alias": "theme"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "readonly": { "alias": "readonly"; "required": false; }; "autoFocus": { "alias": "autoFocus"; "required": false; }; "extensions": { "alias": "extensions"; "required": false; }; }, { "change": "change"; "focus": "focus"; "blur": "blur"; }, never, never, true, never>;
}
